from typing import Mapping

from mashumaro.serializer.base.metaprogramming import CodeBuilder


class DataClassDictMixin:
    def __init_subclass__(cls, **kwargs):
        builder = CodeBuilder(cls)
        builder.add_from_dict()
        builder.add_to_dict()

    def to_dict(
            self,
            use_bytes: bool = False,
            use_enum: bool = False,
            use_datetime: bool = False) -> dict:
        pass

    @classmethod
    def from_dict(
            cls,
            d: Mapping,
            use_bytes: bool = False,
            use_enum: bool = False,
            use_datetime: bool = False):
        pass


__all__ = [DataClassDictMixin]



import yaml

from mashumaro.serializer.base import DataClassDictMixin


class DataClassYAMLMixin(DataClassDictMixin):
    def to_yaml(self):
        return yaml.dump(self.to_dict(), use_bytes=False)

    @classmethod
    def from_yaml(cls, data: bytes):
        return cls.from_dict(yaml.load(data), use_bytes=False)
